@@ -102,6 +102,36 @@ struct if_dqinfo {
 	u_int32_t dqi_valid;
 };
 
+/*
+ * Definitions for quota netlink interface
+ */
+#define QUOTA_NL_NOWARN 0
+#define QUOTA_NL_IHARDWARN 1            /* Inode hardlimit reached */
+#define QUOTA_NL_ISOFTLONGWARN 2        /* Inode grace time expired */
+#define QUOTA_NL_ISOFTWARN 3            /* Inode softlimit reached */
+#define QUOTA_NL_BHARDWARN 4            /* Block hardlimit reached */
+#define QUOTA_NL_BSOFTLONGWARN 5        /* Block grace time expired */
+#define QUOTA_NL_BSOFTWARN 6            /* Block softlimit reached */
+
+enum {
+	QUOTA_NL_C_UNSPEC,
+	QUOTA_NL_C_WARNING,
+	__QUOTA_NL_C_MAX,
+};
+#define QUOTA_NL_C_MAX (__QUOTA_NL_C_MAX - 1)
+
+enum {
+	QUOTA_NL_A_UNSPEC,
+	QUOTA_NL_A_QTYPE,
+	QUOTA_NL_A_EXCESS_ID,
+	QUOTA_NL_A_WARNING,
+	QUOTA_NL_A_DEV_MAJOR,
+	QUOTA_NL_A_DEV_MINOR,
+	QUOTA_NL_A_CAUSED_ID,
+	__QUOTA_NL_A_MAX,
+};
+#define QUOTA_NL_A_MAX (__QUOTA_NL_A_MAX - 1)
+
 /* Quota format identifiers */
 #define QFMT_VFS_OLD 1
 #define QFMT_VFS_V0  2
@@ -116,7 +146,7 @@ struct if_dqinfo {
 		#define FIOQSIZE _IOR('f', 128, loff_t)
 	#elif defined(__arm__) || defined(__mc68000__) || defined(__s390__)
 		#define FIOQSIZE 0x545E
-        #elif defined(__i386__) || defined(__i486__) || defined(__i586__) || defined(__ia64__) || defined(__parisc__) || defined(__cris__) || defined(__hppa__)
+        #elif defined(__i386__) || defined(__i486__) || defined(__i586__) || defined(__ia64__) || defined(__parisc__) || defined(__cris__) || defined(__hppa__) || defined(__x86_64__)
 		#define FIOQSIZE 0x5460
 	#elif defined(__mips__) || defined(__mips64__)
 		#define FIOQSIZE 0x6667
