@@ -11,6 +11,7 @@
 #include <string.h>
 #include <getopt.h>
 #include <time.h>
+#include <ctype.h>
 
 #if defined(RPC)
 #include "rquota.h"
@@ -30,6 +31,8 @@
 #define FL_INDIVIDUAL_GRACE 64
 #define FL_BATCH 128
 #define FL_NUMNAMES 256
+#define FL_NO_MIXED_PATHS 512
+#define FL_CONTINUE_BATCH 1024
 
 int flags, fmt = -1;
 char **mnt;
@@ -42,7 +45,7 @@ struct util_dqblk toset;
 static void usage(void)
 {
 #if defined(RPC_SETQUOTA)
-	char *ropt = "[-r] ";
+	char *ropt = "[-rm] ";
 #else
 	char *ropt = "";
 #endif
@@ -50,7 +53,7 @@ static void usage(void)
   setquota [-u|-g] %1$s[-F quotaformat] <user|group>\n\
 \t<block-softlimit> <block-hardlimit> <inode-softlimit> <inode-hardlimit> -a|<filesystem>...\n\
   setquota [-u|-g] %1$s[-F quotaformat] <-p protouser|protogroup> <user|group> -a|<filesystem>...\n\
-  setquota [-u|-g] %1$s[-F quotaformat] -b -a|<filesystem>...\n\
+  setquota [-u|-g] %1$s[-F quotaformat] -b [-c] -a|<filesystem>...\n\
   setquota [-u|-g] [-F quotaformat] -t <blockgrace> <inodegrace> -a|<filesystem>...\n\
   setquota [-u|-g] [-F quotaformat] <user|group> -T <blockgrace> <inodegrace> -a|<filesystem>...\n\n\
 -u, --user                 set limits for user\n\
@@ -60,9 +63,11 @@ static void usage(void)
                            composed only of digits\n\
 -F, --format=formatname    operate on specific quota format\n\
 -p, --prototype=protoname  copy limits from user/group\n\
--b, --batch                read limits from standard input\n"), ropt);
+-b, --batch                read limits from standard input\n\
+-c, --continue-batch       continue in input processing in case of an error\n"), ropt);
 #if defined(RPC_SETQUOTA)
-	fputs(_("-r, --remote               set remote quota (via RPC)\n"), stderr);
+	fputs(_("-r, --remote               set remote quota (via RPC)\n\
+-m, --no-mixed-pathnames      trim leading slashes from NFSv4 mountpoints\n"), stderr);
 #endif
 	fputs(_("-t, --edit-period          edit grace period\n\
 -T, --edit-times           edit grace times for user/group\n\
@@ -102,9 +107,9 @@ static void parse_options(int argcnt, char **argstr)
 	char *protoname = NULL;
 
 #ifdef RPC_SETQUOTA
-	char *opts = "gp:urVF:taTb";
+	char *opts = "gp:urmVF:taTbc";
 #else
-	char *opts = "gp:uVF:taTb";
+	char *opts = "gp:uVF:taTbc";
 #endif
 	struct option long_opts[] = {
 		{ "user", 0, NULL, 'u' },
@@ -112,12 +117,14 @@ static void parse_options(int argcnt, char **argstr)
 		{ "prototype", 1, NULL, 'p' },
 #ifdef RPC_SETQUOTA
 		{ "remote", 0, NULL, 'r' },
+		{ "no-mixed-pathnames", 0, NULL, 'm' },
 #endif
 		{ "all", 0, NULL, 'a' },
 		{ "always-resolve", 0, NULL, 256},
 		{ "edit-period", 0, NULL, 't' },
 		{ "edit-times", 0, NULL, 'T' },
 		{ "batch", 0, NULL, 'b' },
+		{ "continue", 0, NULL, 'c' },
 		{ "format", 1, NULL, 'F' },
 		{ "version", 0, NULL, 'V' },
 		{ "help", 0, NULL, 'h' },
@@ -142,6 +149,9 @@ static void parse_options(int argcnt, char **argstr)
 		  case 'r':
 			  flags |= FL_RPC;
 			  break;
+		  case 'm':
+			  flags |= FL_NO_MIXED_PATHS;
+			  break;
 		  case 'a':
 			  flags |= FL_ALL;
 			  break;
@@ -154,6 +164,9 @@ static void parse_options(int argcnt, char **argstr)
 		  case 'b':
 			  flags |= FL_BATCH;
 			  break;
+		  case 'c':
+			  flags |= FL_CONTINUE_BATCH;
+			  break;
 		  case 'T':
 			  flags |= FL_INDIVIDUAL_GRACE;
 			  break;
@@ -278,28 +291,50 @@ static int setlimits(struct quota_handle **handles)
 	return ret;
 }
 
-#define MAXLINELEN (MAXNUMLEN*4+MAXNAMELEN+16)
+#define MAXLINELEN 65536
 
 /* Read & parse one batch entry */
 static int read_entry(qid_t *id, qsize_t *isoftlimit, qsize_t *ihardlimit, qsize_t *bsoftlimit, qsize_t *bhardlimit)
 {
 	static int line = 0;
 	char name[MAXNAMELEN+1];
+	char linebuf[MAXLINELEN], *chptr;
 	unsigned long is, ih, bs, bh;
 	int ret;
 
-	do {
+	while (1) {
 		line++;
-		ret = scanf("%s %lu %lu %lu %lu", name, &bs, &bh, &is, &ih);
-		if (ret == -1)
+		if (!fgets(linebuf, sizeof(linebuf), stdin))
 			return -1;
-		if (ret != 5)
-			die(1, _("Cannot parse input line %d.\n"), line);
-		ret = 0;
+		if (linebuf[strlen(linebuf)-1] != '\n')
+			die(1, _("Line %d too long.\n"), line);
+		/* Comment? */
+		if (linebuf[0] == '#')
+			continue;
+		/* Blank line? */
+		chptr = linebuf;
+		while (isblank(*chptr))
+			chptr++;
+		if (*chptr == '\n')
+			continue;
+		ret = sscanf(chptr, "%s %lu %lu %lu %lu", name, &bs, &bh, &is, &ih);
+		if (ret != 5) {
+			errstr(_("Cannot parse input line %d.\n"), line);
+			if (!(flags & FL_CONTINUE_BATCH))
+				die(1, _("Exitting.\n"));
+			errstr(_("Skipping line.\n"));
+			continue;
+		}
 		*id = name2id(name, flag2type(flags), !!(flags & FL_NUMNAMES), &ret);
-		if (ret)
-			errstr(_("Unable to get name '%s'.\n"), name);
-	} while (ret);
+		if (ret) {
+			errstr(_("Unable to resolve name '%s' on line %d.\n"), name, line);
+			if (!(flags & FL_CONTINUE_BATCH))
+				die(1, _("Exitting.\n"));
+			errstr(_("Skipping line.\n"));
+			continue;
+		}
+		break;
+	}
 	*isoftlimit = is;
 	*ihardlimit = ih;
 	*bsoftlimit = bs;
@@ -375,9 +410,13 @@ int main(int argc, char **argv)
 	init_kernel_interface();
 
 	if (flags & FL_ALL)
-		handles = create_handle_list(0, NULL, flag2type(flags), fmt, 0, (flags & FL_RPC) ? 0 : MS_LOCALONLY);
+		handles = create_handle_list(0, NULL, flag2type(flags), fmt,
+			(flags & FL_NO_MIXED_PATHS) ? 0 : IOI_NFS_MIXED_PATHS,
+			(flags & FL_RPC) ? 0 : MS_LOCALONLY);
 	else
-		handles = create_handle_list(mntcnt, mnt, flag2type(flags), fmt, 0, (flags & FL_RPC) ? 0 : MS_LOCALONLY);
+		handles = create_handle_list(mntcnt, mnt, flag2type(flags), fmt,
+			(flags & FL_NO_MIXED_PATHS) ? 0 : IOI_NFS_MIXED_PATHS,
+			(flags & FL_RPC) ? 0 : MS_LOCALONLY);
 
 	if (flags & FL_GRACE)
 		ret = setgraces(handles);
